use tracing_subscriber::filter::LevelFilter;

mod config;
mod db;
mod template;
mod web;

#[tokio::main(flavor = "current_thread")]
async fn main() -> anyhow::Result<()> {
    tracing_subscriber::fmt()
        .with_max_level(LevelFilter::DEBUG)
        .init();
    let config = config::Config::load()?;
    let db = db::Db::new(&config.db_conn).await?;
    let web = web::WebServer::new(config.listen, db, config.image_path)?;

    web.server.await?;

    Ok(())
}
